from OFS import SimpleItem

from Globals import DTMLFile
from WinAmp import winamp, getTrackList
import os
import os.path

class Jukebox(SimpleItem.SimpleItem):

    """
    A Jukebox product to control WinAmp from Zope
    """

    meta_type = 'Jukebox'

    manage_options = (
        {'label': 'Properties', 'action': 'manage_editForm',},
        {'label': 'View', 'action': 'index_html',},
    )

    def __init__(self, id, title, winampPath):
        "Inits the product with default values"
        self.id = id
        self.title = title
        self.winampPath = winampPath

    def waInstance(self):
        return winamp(self.winampPath)

    def manage_editAction(self, title, winampPath, RESPONSE=None):
        "Changes the product values"
        self.title = title
        self.winampPath = winampPath
        self._p_changed = 1
        RESPONSE.redirect('manage_editForm')

    def playList(self, asHtml=1):
        "returns the current playlist of winamp"
        # dump the list
        w=self.waInstance()
        w.dumpList()
        lst=getTrackList( os.path.join( self.winampPath, 'winamp.m3u' ) )
        if not asHtml:
            return lst

        res='<table border=0>'
        i=0
        for s in lst:
            res+='<tr><td><a href="playSong?iTrackNumber:int=%d">%s</a></td></tr>' % (i,s)
            i+=1
        res+='</table>'
        res+='<br><a href="prevSong">&nbsp;<< Prev</a>&nbsp;<a href="play">Play</a>&nbsp;<a href="pause">Pause</a>&nbsp;<a href="stop">Stop</a>&nbsp;<a href="nextSong">Next >><a/>'
        return res

    def nowPlaying(self):
        "returns the name of the current song"
        return self.waInstance().getCurrentTrackName()

    def addToPlayList(self, songPath):
        'add a path to the play list'
        return self.waInstance().addToPlayList(songPath)

    def playSong(self, iTrackNumber):
        'Play a song in WinAmp'
        return self.waInstance().playSong(iTrackNumber)

    def prevSong(self):
        'play previous song'
        return self.waInstance().command('prev')

    def nextSong(self):
        'play next song'
        return self.waInstance().command('next')

    def pause(self):
        'play next song'
        return self.waInstance().command('pause')

    def play(self):
        'play current song'
        return self.waInstance().command('play')

    def stop(self):
        'stop current song'
        return self.waInstance().command('stop')

    index_html = DTMLFile('www/index_html',
                          globals()) # Used to view content of the object

    manage_editForm = DTMLFile('www/manage_editForm',
                                globals()) # Edit the content of the object

# constructor pages. Only used when the product is added to a folder.

def manage_addJukeboxAction(self, id='Jukebox', title='Title here',
                            winampPath='C:\\Program Files\\Winamp', REQUEST=None):
    "Add a jukebox to a folder."
    self._setObject(id, Jukebox(id, title, winampPath))
    if REQUEST is not None:
        return self.manage_main(self, REQUEST)

manage_addJukeboxForm = DTMLFile('www/manage_addJukeboxForm',
                                  globals()) # Get user id from this form
